@@ -1,4 +1,4 @@
-# Copyright 2010-2017 Meik Michalke <meik.michalke@hhu.de>
+# Copyright 2010-2019 Meik Michalke <meik.michalke@hhu.de>
 #
 # This file is part of the R package koRpus.
 #
@@ -22,8 +22,8 @@
 #' For details, please refer to the documentation for the generic
 #' \code{\link[sylly:hyphen]{hyphen}} method in the \code{sylly} package.
 #'
-#' @param words Either an object of class \code{\link[koRpus:kRp.tagged-class]{kRp.tagged}}, \code{\link[koRpus:kRp.txt.freq-class]{kRp.txt.freq}} or
-#'    \code{\link[koRpus:kRp.analysis-class]{kRp.analysis}}, or a character vector with words to be hyphenated.
+#' @param words Either an object of class \code{\link[koRpus:kRp.text-class]{kRp.text}},
+#'    or a character vector with words to be hyphenated.
 #' @param hyph.pattern Either an object of class \code{\link[sylly:kRp.hyph.pat-class]{kRp.hyph.pat}}, or
 #'    a valid character string naming the language of the patterns to be used. See details.
 #' @param min.length Integer, number of letters a word must have for considering a hyphenation. \code{hyphen} will
@@ -31,7 +31,7 @@
 #' @param rm.hyph Logical, whether appearing hyphens in words should be removed before pattern matching.
 #' @param corp.rm.class A character vector with word classes which should be ignored. The default value
 #'    \code{"nonpunct"} has special meaning and will cause the result of
-#'    \code{kRp.POS.tags(lang, c("punct","sentc"), list.classes=TRUE)} to be used. Relevant only if \code{words}
+#'    \code{kRp.POS.tags(lang, tags=c("punct","sentc"), list.classes=TRUE)} to be used. Relevant only if \code{words}
 #'    is a valid koRpus object.
 #' @param corp.rm.tag A character vector with POS tags which should be ignored. Relevant only if \code{words}
 #'    is a valid koRpus object.
@@ -43,8 +43,12 @@
 #' @param as A character string defining the class of the object to be returned. Defaults to \code{"kRp.hyphen"}, but can also be
 #'    set to \code{"data.frame"} or \code{"numeric"}, returning only the central \code{data.frame} or the numeric vector of counted syllables,
 #'    respectively. For the latter two options, you can alternatively use the shortcut methods \code{hyphen_df} or  \code{hyphen_c}.
-#' @return An object of class \code{\link[sylly:kRp.hyphen-class]{kRp.hyphen}}, \code{data.frame} or a numeric vector, depending on the value
-#'    of the \code{as} argument.
+#'    Ignored if \code{as.feature=TRUE}.
+#' @param as.feature Logical, whether the output should be just the analysis results or the input object with
+#'    the results added as a feature. Use \code{\link[koRpus:corpusHyphen]{corpusHyphen}} to get the results from such an aggregated object.
+#'    If set to \code{TRUE}, \code{as="kRp.hyphen"} is automatically set, overwriting other setting of \code{as} with a warning.
+#' @return An object of class \code{\link[koRpus:kRp.text-class]{kRp.text}}, \code{\link[sylly:kRp.hyphen-class]{kRp.hyphen}},
+#'    \code{data.frame} or a numeric vector, depending on the values of the \code{as} and \code{as.feature} arguments.
 #' @keywords hyphenation
 # @author m.eik michalke \email{meik.michalke@@hhu.de}
 #' @seealso
@@ -64,26 +68,41 @@
 #' hyphen(tagged.text)
 #' }
 #' @export
-#' @include 01_class_01_kRp.tagged.R
-#' @include 01_class_03_kRp.txt.freq.R
-#' @include 01_class_04_kRp.txt.trans.R
-#' @include 01_class_05_kRp.analysis.R
+#' @include 01_class_01_kRp.text.R
 #' @include koRpus-internal.R
 #' @aliases
 #'    hyphen
-#'    hyphen,kRp.taggedText-method
+#'    hyphen,kRp.text-method
 #' @rdname hyphen-methods
 
 ####################################################################################
 ## if this signature changes, check kRp.hyphen.calc() in 'sylly' package as well! ##
 ####################################################################################
 
-setMethod("hyphen", signature(words="kRp.taggedText"), function(words,
-    hyph.pattern=NULL, min.length=4, rm.hyph=TRUE,
+setMethod(
+  "hyphen",
+  signature(words="kRp.text"),
+  function(
+    words,
+    hyph.pattern=NULL,
+    min.length=4,
+    rm.hyph=TRUE,
     corp.rm.class="nonpunct",
-    corp.rm.tag=c(), quiet=FALSE, cache=TRUE, as="kRp.hyphen"){
+    corp.rm.tag=c(),
+    quiet=FALSE,
+    cache=TRUE,
+    as="kRp.hyphen",
+    as.feature=FALSE
+  ){
 
-    # get class kRp.tagged from words object
+    if(isTRUE(as.feature)){
+      words_orig <- words
+      if(any(as != "kRp.hyphen")){
+        warning("Overwriting setting of \"as\" with \"kRp.hyphen\" because \"as.feature=TRUE\"!")
+        as <- "kRp.hyphen"
+      } else {}
+    } else {}
+    # get class kRp.text from words object
     # the internal function tag.kRp.txt() will return the object unchanged if it
     # is already tagged, so it's safe to call it with the lang set here
     tagged.text <- tag.kRp.txt(words, objects.only=TRUE)
@@ -97,15 +116,20 @@ setMethod("hyphen", signature(words="kRp.taggedText"), function(words,
     results <- sylly::hyphen(words=words, hyph.pattern=hyph.pattern, min.length=min.length,
       rm.hyph=rm.hyph, quiet=quiet, cache=cache, as=as)
 
-    return(results)
+    if(isTRUE(as.feature)){
+      corpusHyphen(words_orig) <- results
+      return(words_orig)
+    } else {
+      return(results)
+    }
   }
 )
 
 #' @export
 #' @importFrom sylly hyphen_df
-#' @aliases hyphen_df,kRp.taggedText-method
+#' @aliases hyphen_df,kRp.text-method
 #' @rdname hyphen-methods
-setMethod("hyphen_df", signature(words="kRp.taggedText"), function(words,
+setMethod("hyphen_df", signature(words="kRp.text"), function(words,
     hyph.pattern=NULL, min.length=4, rm.hyph=TRUE, quiet=FALSE, cache=TRUE){
 
     results <- hyphen(words=words, hyph.pattern=hyph.pattern, min.length=min.length,
@@ -117,9 +141,9 @@ setMethod("hyphen_df", signature(words="kRp.taggedText"), function(words,
 
 #' @export
 #' @importFrom sylly hyphen_c
-#' @aliases hyphen_c,kRp.taggedText-method
+#' @aliases hyphen_c,kRp.text-method
 #' @rdname hyphen-methods
-setMethod("hyphen_c", signature(words="kRp.taggedText"), function(words,
+setMethod("hyphen_c", signature(words="kRp.text"), function(words,
     hyph.pattern=NULL, min.length=4, rm.hyph=TRUE, quiet=FALSE, cache=TRUE){
 
     results <- hyphen(words=words, hyph.pattern=hyph.pattern, min.length=min.length,
